pub trait Concat<const HI: usize> {
type Output: Integer;
}Expand description
Define the result of concatenating two numbers into a “wide” value.
pub trait Concat<const HI: usize> {
type Output: Integer;
}Define the result of concatenating two numbers into a “wide” value.