SplitEven

Trait SplitEven 

pub trait SplitEven {
    type Output: Integer;
}
Define the result of splitting a number into two parts, with each part having an equal width.

Required Associated Types

type Output: Integer

Split output: each component having half the width of Self.

Implementors

Source

impl SplitEven for U128

Source

type Output = Uint<{ <$name>::LIMBS / 2 }>

Source

impl SplitEven for U256

Source

type Output = Uint<{ <$name>::LIMBS / 2 }>

Source

impl SplitEven for U384

Source

type Output = Uint<{ <$name>::LIMBS / 2 }>

Source

impl SplitEven for U512

Source

type Output = Uint<{ <$name>::LIMBS / 2 }>

Source

impl SplitEven for U640

Source

type Output = Uint<{ <$name>::LIMBS / 2 }>

Source

impl SplitEven for U768

Source

type Output = Uint<{ <$name>::LIMBS / 2 }>

Source

impl SplitEven for U896

Source

type Output = Uint<{ <$name>::LIMBS / 2 }>

Source

impl SplitEven for U1024

Source

type Output = Uint<{ <$name>::LIMBS / 2 }>

Source

impl SplitEven for U1280

Source

type Output = Uint<{ <$name>::LIMBS / 2 }>

Source

impl SplitEven for U1536

Source

type Output = Uint<{ <$name>::LIMBS / 2 }>

Source

impl SplitEven for U1792

Source

type Output = Uint<{ <$name>::LIMBS / 2 }>

Source

impl SplitEven for U2048

Source

type Output = Uint<{ <$name>::LIMBS / 2 }>

Source

impl SplitEven for U3072

Source

type Output = Uint<{ <$name>::LIMBS / 2 }>

Source

impl SplitEven for U3584

Source

type Output = Uint<{ <$name>::LIMBS / 2 }>

Source

impl SplitEven for U4096

Source

type Output = Uint<{ <$name>::LIMBS / 2 }>

Source

impl SplitEven for U4224

Source

type Output = Uint<{ <$name>::LIMBS / 2 }>

Source

impl SplitEven for U4352

Source

type Output = Uint<{ <$name>::LIMBS / 2 }>

Source

impl SplitEven for U6144

Source

type Output = Uint<{ <$name>::LIMBS / 2 }>

Source

impl SplitEven for U8192

Source

type Output = Uint<{ <$name>::LIMBS / 2 }>

Source

impl SplitEven for U16384

Source

type Output = Uint<{ <$name>::LIMBS / 2 }>