pub trait SplitEven { type Output: Integer; }
Define the result of splitting a number into two parts, with each part having an equal width.
Split output: each component having half the width of Self.
Self